@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef REQUEST_P_H
-#define REQUEST_P_H
+#ifndef QYOUTUBE_REQUEST_P_H
+#define QYOUTUBE_REQUEST_P_H
 
 #include "request.h"
 #include "json.h"
@@ -42,7 +42,6 @@ inline void addUrlQueryItems(QUrlQuery *query, const QVariantMap &map) {
 #endif
     QMapIterator<QString, QVariant> iterator(map);
     QByteArray value;
-    bool ok;
     
     while (iterator.hasNext()) {
         iterator.next();
@@ -53,13 +52,11 @@ inline void addUrlQueryItems(QUrlQuery *query, const QVariantMap &map) {
             value = iterator.value().toByteArray();
             break;
         default:
-            value = QtJson::Json::serialize(iterator.value(), ok);
+            value = QtJson::Json::serialize(iterator.value());
             break;
         }
         
-        if (ok) {
-            query->addQueryItem(iterator.key(), value);
-        }
+        query->addQueryItem(iterator.key(), value);
     }
 }
 #else
@@ -69,7 +66,6 @@ inline void addUrlQueryItems(QUrl *url, const QVariantMap &map) {
 #endif
     QMapIterator<QString, QVariant> iterator(map);
     QByteArray value;
-    bool ok;
     
     while (iterator.hasNext()) {
         iterator.next();
@@ -80,13 +76,11 @@ inline void addUrlQueryItems(QUrl *url, const QVariantMap &map) {
             value = iterator.value().toByteArray();
             break;
         default:
-            value = QtJson::Json::serialize(iterator.value(), ok);
+            value = QtJson::Json::serialize(iterator.value());
             break;
         }
         
-        if (ok) {
-            url->addQueryItem(iterator.key(), value);
-        }
+        url->addQueryItem(iterator.key(), value);
     }
 }
 #endif
@@ -97,7 +91,6 @@ inline void addRequestHeaders(QNetworkRequest *request, const QVariantMap &map)
 #endif
     QMapIterator<QString, QVariant> iterator(map);
     QByteArray value;
-    bool ok;
     
     while (iterator.hasNext()) {
         iterator.next();
@@ -108,13 +101,11 @@ inline void addRequestHeaders(QNetworkRequest *request, const QVariantMap &map)
             value = iterator.value().toByteArray();
             break;
         default:
-            value = QtJson::Json::serialize(iterator.value(), ok);
+            value = QtJson::Json::serialize(iterator.value());
             break;
         }
         
-        if (ok) {
-            request->setRawHeader(iterator.key().toUtf8(), value);
-        }
+        request->setRawHeader(iterator.key().toUtf8(), value);
     }
 }
 
@@ -124,7 +115,6 @@ inline void addPostBody(QString *body, const QVariantMap &map) {
 #endif
     QMapIterator<QString, QVariant> iterator(map);
     QByteArray value;
-    bool ok;
     
     while (iterator.hasNext()) {
         iterator.next();
@@ -135,16 +125,14 @@ inline void addPostBody(QString *body, const QVariantMap &map) {
             value = iterator.value().toByteArray();
             break;
         default:
-            value = QtJson::Json::serialize(iterator.value(), ok);
+            value = QtJson::Json::serialize(iterator.value());
             break;
         }
         
-        if (ok) {
-            body->append(iterator.key() + "=" + value);
-            
-            if (iterator.hasNext()) {
-                body->append("&");
-            }
+        body->append(iterator.key() + "=" + value);
+        
+        if (iterator.hasNext()) {
+            body->append("&");
         }
     }
 }
@@ -215,4 +203,4 @@ public:
 
 }
 
-#endif // REQUEST_P_H
+#endif // QYOUTUBE_REQUEST_P_H
